mysql.util

Package mysql :: Package util |
[hide private]
[frames] | no frames]

# Package util

source code
Subpackage of internal utility modules.

Submodules | [hide private]
mysql.util._c_only: Internal module of C helper functions. mysql.util.misc: Miscellaneous utility functions. mysql.util.string: Internal string manipulation routines.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.3 $'